@@ -37,12 +37,15 @@ public:
     UObject *object;
 };
 
+void t_uobject_dealloc(t_uobject *self);
+
 extern PyTypeObject UObjectType;
 extern PyTypeObject FormattableType;
 
 PyObject *wrap_StringEnumeration(StringEnumeration *, int);
 PyObject *wrap_Formattable(Formattable *, int);
 PyObject *wrap_Formattable(Formattable &);
+PyObject *wrap_UnicodeString(UnicodeString *, int);
 
 
 void _init_bases(PyObject *m);
